* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Advanced Settings](https://help.sap.com/docs/leanix/ea/advanced-settings)
  * Downloading Reports from the SAP LeanIX Store
